==> go.php?file=PhoenixStyle1.566.zip: PhoenixStyle/Modules/Modfile.lua <==
﻿function psdeathrepevent(type,name,guid,spellid,spellname,dmg,overkill,crit,whokill,resist,block,absorbed,spellschool)
--type: 0=death, 1 - instakill, 2 - ENVIRONMENTAL_DAMAGE, 10 - normal damage


--общие изменения
if dmg and overkill then
  dmg=dmg-overkill
end

if whokill==nil then
  whokill=""
end

local crittxt1=""
if crit then
  crittxt1="|cffff0000"..psdrcrit.."|r. "
end

local resisttxt1=""
if resist and block and absorbed then
  if resist>0 then
    resisttxt1=resisttxt1.."Resist: "..psdamageceil(resist)
  end
  if block>0 then
    if string.len(resisttxt1)>2 then
      resisttxt1=resisttxt1..", "
    end
    resisttxt1=resisttxt1.."Block: "..psdamageceil(block)
  end
  if absorbed>0 then
    if string.len(resisttxt1)>2 then
      resisttxt1=resisttxt1..", "
    end
    resisttxt1=resisttxt1.."Absorb: "..psdamageceil(absorbed)
  end
end
if string.len(resisttxt1)>2 then
  resisttxt1=", "..resisttxt1
end

local spellsk=""
if spellschool then
  if spellschool==1 then
  elseif spellschool==2 then
    spellsk=psspellschool1
  elseif spellschool==4 then
    spellsk=psspellschool2
  elseif spellschool==8 then
    spellsk=psspellschool3
  elseif spellschool==16 then
    spellsk=psspellschool4
  elseif spellschool==32 then
    spellsk=psspellschool5
  elseif spellschool==64 then
    spellsk=psspellschool6
  elseif spellschool==3 then
    spellsk="Holystrike"
  elseif spellschool==5 then
    spellsk="Flamestrike"
  elseif spellschool==6 then
    spellsk="Holyfire"
  elseif spellschool==9 then
    spellsk="Stormstrike"
  elseif spellschool==10 then
    spellsk="Holystorm"
  elseif spellschool==12 then
    spellsk="Firestorm"
  elseif spellschool==17 then
    spellsk="Froststrike"
  elseif spellschool==18 then
    spellsk="Holyfrost"
  elseif spellschool==20 then
    spellsk="Frostfire"
  elseif spellschool==24 then
    spellsk="Froststorm"
  elseif spellschool==33 then
    spellsk="Shadowstrike"
  elseif spellschool==34 then
    spellsk="Shadowlight (Twilight)"
  elseif spellschool==36 then
    spellsk="Shadowflame"
  elseif spellschool==40 then
    spellsk="Shadowstorm (Plague)"
  elseif spellschool==48 then
    spellsk="Shadowfrost"
  elseif spellschool==65 then
    spellsk="Spellstrike"
  elseif spellschool==66 then
    spellsk="Divine"
  elseif spellschool==68 then
    spellsk="Spellfire"
  elseif spellschool==72 then
    spellsk="Spellstorm"
  elseif spellschool==80 then
    spellsk="Spellfrost"
  elseif spellschool==96 then
    spellsk="Spellshadow"
  elseif spellschool==28 then
    spellsk="Elemental"
  elseif spellschool==124 then
    spellsk="Chromatic"
  elseif spellschool==126 then
    spellsk="Magic"
  elseif spellschool==127 then
    spellsk="Chaos"
  end
end
if string.len(spellsk)>2 then
  spellsk=" ("..spellsk..")"
end


--проверка на игрока
psunitisplayer(guid,name)
if psunitplayertrue then
  --проверка что его смерть не анонсили в течении 3 сек
  local anonsed=0
  local addedtab=0
  if #pslastdeath[1]>0 then
    for i=1,#pslastdeath[1] do
      if pslastdeath[1][i]==name then
        if GetTime()<pslastdeath[2][i]+3 then
          anonsed=1
        else
          pslastdeath[2][i]=GetTime()
          addedtab=1
        end
      end
    end
  end
  --не анонсилось:
  if anonsed==0 then
    if addedtab==0 then
      table.insert(pslastdeath[1],name)
      local tm=GetTime()
      table.insert(pslastdeath[2],tm)
    end
    --получение фразы для репорта!!!!!!!!!!!!! 1 - цветное
    local txt1=""
    txt1=txt1..psaddcolortxt(1,name)..name..psaddcolortxt(2,name).." > "
    if type==0 then
      txt1=txt1.."|cffff0000"..psiccunknown.."|r"
    elseif type==1 then
      txt1=txt1..spellname.." (|cffff0000"..psdrinstakill.."|r)"
    elseif type==2 then
      txt1=txt1..psdamageceil(dmg)..", |cffff0000"..spellname.."|r ("..psoverkill..": "..psdamageceil(overkill)..")"
    else
      txt1=txt1..psdamageceil(dmg)..", "..spellname.." ("..psoverkill..": "..psdamageceil(overkill)..resisttxt1..") "..crittxt1.."["..whokill.."]"..spellsk
    end
    --проверяем есть ли хоть 1 босс активный, если да - отправляем туда репорт!
    psdeathrepfindactiveboss()
    if psdeathrepbossnametemp then
      pscaststartinfo(0,txt1, -1, "id1", 666, psdreventname,psdeathrepbossnametemp,2)
      psdeathrepbossnametemp=nil
    else
      table.insert(psdeathwaiting[1],txt1)
      local timeevent=pscombatstarttime-GetTime()
      table.insert(psdeathwaiting[2],timeevent)
    end
  end
end
    
    
    





end



function psdeathrepfindactiveboss()
  if pswasonboss11 then
    psdeathrepbossnametemp=psbossnames[1][1]
  elseif pswasonboss12 then
    psdeathrepbossnametemp=psbossnames[1][2]
  elseif pswasonboss13 then
    psdeathrepbossnametemp=psbossnames[1][3]
  elseif pswasonboss21 then
    psdeathrepbossnametemp=psbossnames[2][1]
  elseif pswasonboss22 then
    psdeathrepbossnametemp=psbossnames[2][2]
  elseif pswasonboss23 then
    psdeathrepbossnametemp=psbossnames[2][3]
  elseif pswasonboss24 then
    psdeathrepbossnametemp=psbossnames[2][4]
  elseif pswasonboss25 then
    psdeathrepbossnametemp=psbossnames[2][5]
  elseif pswasonboss26 then
    psdeathrepbossnametemp=psbossnames[2][6]
  elseif pswasonboss31 then
    psdeathrepbossnametemp=psbossnames[3][1]
  elseif pswasonboss32 then
    psdeathrepbossnametemp=psbossnames[3][2]
  elseif pswasonboss33 then
    psdeathrepbossnametemp=psbossnames[3][3]
  elseif pswasonboss34 then
    psdeathrepbossnametemp=psbossnames[3][4]
  elseif pswasonboss35 then
    psdeathrepbossnametemp=psbossnames[3][5]
  elseif pswasonboss41 then
    psdeathrepbossnametemp=psbossnames[4][1]
  elseif pswasonboss42 then
    psdeathrepbossnametemp=psbossnames[4][2]
  elseif pswasonboss51 then
    psdeathrepbossnametemp=psbossnames[5][1]
  elseif pswasonboss52 then
    psdeathrepbossnametemp=psbossnames[5][2]
  elseif pswasonboss53 then
    psdeathrepbossnametemp=psbossnames[5][3]
  elseif pswasonboss54 then
    psdeathrepbossnametemp=psbossnames[5][4]
  elseif pswasonboss55 then
    psdeathrepbossnametemp=psbossnames[5][5]
  elseif pswasonboss56 then
    psdeathrepbossnametemp=psbossnames[5][6]
  elseif pswasonboss57 then
    psdeathrepbossnametemp=psbossnames[5][7]
  elseif pswasonboss61 then
    psdeathrepbossnametemp=psbossnames[6][1]
  elseif pswasonboss62 then
    psdeathrepbossnametemp=psbossnames[6][2]
  elseif pswasonboss63 then
    psdeathrepbossnametemp=psbossnames[6][3]
  elseif pswasonboss64 then
    psdeathrepbossnametemp=psbossnames[6][4]
  elseif pswasonboss65 then
    psdeathrepbossnametemp=psbossnames[6][5]
  elseif pswasonboss66 then
    psdeathrepbossnametemp=psbossnames[6][6]
  elseif pswasonboss67 then
    psdeathrepbossnametemp=psbossnames[6][7]
  elseif pswasonboss68 then
    psdeathrepbossnametemp=psbossnames[6][8]
  else
    psdeathrepbossnametemp=nil
  end
end


--не забыть учесть, если игрок УМИРАЕТ ОТ АБИЛКИ что я и так анонсю ФС - и чаты анонсов СОВПАДАЮТ!!! тогда я не анонсю это в фаталити, но засчитываю как номер смерти
--репорты ведь задерживаются прилично, для сбора доп инфы, задерживать фаталити на 3 сек? не много ли ?

==> go.php?file=PhoenixStyle1.567.zip: PhoenixStyle/Modules/Modfile.lua <==
﻿function psdeathrepevent(type,name,guid,spellid,spellname,dmg,overkill,crit,whokill,resist,block,absorbed,spellschool)
--type: 0=death, 1 - instakill, 2 - ENVIRONMENTAL_DAMAGE, 10 - normal damage

--табл для сохр килла
if pskillreport==nil then
  pskillreport={{},{}} --фраза в ожидании, время записи
end


--общие изменения
if dmg and overkill then
  dmg=dmg-overkill
end

if whokill==nil then
  whokill=""
end

local crittxt1=""
if crit then
  crittxt1="|cffff0000"..psdrcrit.."|r. "
end

local resisttxt1=""
if resist and block and absorbed then
  if resist>0 then
    resisttxt1=resisttxt1.."Resist: "..psdamageceil(resist)
  end
  if block>0 then
    if string.len(resisttxt1)>2 then
      resisttxt1=resisttxt1..", "
    end
    resisttxt1=resisttxt1.."Block: "..psdamageceil(block)
  end
  if absorbed>0 then
    if string.len(resisttxt1)>2 then
      resisttxt1=resisttxt1..", "
    end
    resisttxt1=resisttxt1.."Absorb: "..psdamageceil(absorbed)
  end
end
if string.len(resisttxt1)>2 then
  resisttxt1=", "..resisttxt1
end

local spellsk=""
if spellschool then
  if spellschool==1 then
  elseif spellschool==2 then
    spellsk=psspellschool1
  elseif spellschool==4 then
    spellsk=psspellschool2
  elseif spellschool==8 then
    spellsk=psspellschool3
  elseif spellschool==16 then
    spellsk=psspellschool4
  elseif spellschool==32 then
    spellsk=psspellschool5
  elseif spellschool==64 then
    spellsk=psspellschool6
  elseif spellschool==3 then
    spellsk="Holystrike"
  elseif spellschool==5 then
    spellsk="Flamestrike"
  elseif spellschool==6 then
    spellsk="Holyfire"
  elseif spellschool==9 then
    spellsk="Stormstrike"
  elseif spellschool==10 then
    spellsk="Holystorm"
  elseif spellschool==12 then
    spellsk="Firestorm"
  elseif spellschool==17 then
    spellsk="Froststrike"
  elseif spellschool==18 then
    spellsk="Holyfrost"
  elseif spellschool==20 then
    spellsk="Frostfire"
  elseif spellschool==24 then
    spellsk="Froststorm"
  elseif spellschool==33 then
    spellsk="Shadowstrike"
  elseif spellschool==34 then
    spellsk="Shadowlight (Twilight)"
  elseif spellschool==36 then
    spellsk="Shadowflame"
  elseif spellschool==40 then
    spellsk="Shadowstorm (Plague)"
  elseif spellschool==48 then
    spellsk="Shadowfrost"
  elseif spellschool==65 then
    spellsk="Spellstrike"
  elseif spellschool==66 then
    spellsk="Divine"
  elseif spellschool==68 then
    spellsk="Spellfire"
  elseif spellschool==72 then
    spellsk="Spellstorm"
  elseif spellschool==80 then
    spellsk="Spellfrost"
  elseif spellschool==96 then
    spellsk="Spellshadow"
  elseif spellschool==28 then
    spellsk="Elemental"
  elseif spellschool==124 then
    spellsk="Chromatic"
  elseif spellschool==126 then
    spellsk="Magic"
  elseif spellschool==127 then
    spellsk="Chaos"
  end
end
if string.len(spellsk)>2 then
  spellsk=" ("..spellsk..")"
end


--проверка на игрока
psunitisplayer(guid,name)
if psunitplayertrue then
  --проверка что его смерть не анонсили в течении 3 сек и 7 сек если неизвестно!
  local anonsed=0
  local addedtab=0
  if #pslastdeath[1]>0 then
    for i=1,#pslastdeath[1] do
      if pslastdeath[1][i]==name then
        if ((GetTime()<pslastdeath[2][i]+3 and type~=0) or (GetTime()<pslastdeath[2][i]+7 and type==0)) then
          anonsed=1
        else
          pslastdeath[2][i]=GetTime()
          addedtab=1
        end
      end
    end
  end
  --не анонсилось:
  if anonsed==0 then
    if addedtab==0 then
      table.insert(pslastdeath[1],name)
      local tm=GetTime()
      table.insert(pslastdeath[2],tm)
    end
    --получение фразы для репорта!!!!!!!!!!!!! 1 - цветное
    local txt1=""
    txt1=txt1..psaddcolortxt(1,name)..name..psaddcolortxt(2,name).." > "
    if type==0 then
      txt1=txt1.."|cffff0000"..psiccunknown.."|r"
    elseif type==1 then
      txt1=txt1..spellname.." (|cffff0000"..psdrinstakill.."|r)"
    elseif type==2 then
      txt1=txt1..psdamageceil(dmg)..", |cffff0000"..spellname.."|r"
    else
      txt1=txt1..psdamageceil(dmg)..", "..spellname.." ("..psoverkill..": "..psdamageceil(overkill)..resisttxt1..") "..crittxt1.."["..whokill.."]"..spellsk
    end
    --проверяем есть ли хоть 1 босс активный, если да - отправляем туда репорт!
    psdeathrepfindactiveboss()
    if psdeathrepbossnametemp then
      pscaststartinfo(0,txt1, -1, "id1", 666, psdreventname,psdeathrepbossnametemp,2)
      psdeathrepbossnametemp=nil
    else
      table.insert(psdeathwaiting[1],txt1)
      local timeevent=pscombatstarttime-GetTime()
      table.insert(psdeathwaiting[2],timeevent)
    end
  end
end
    
    
    





end



function psdeathrepfindactiveboss()
  if pswasonboss11 then
    psdeathrepbossnametemp=psbossnames[1][1]
  elseif pswasonboss12 then
    psdeathrepbossnametemp=psbossnames[1][2]
  elseif pswasonboss13 then
    psdeathrepbossnametemp=psbossnames[1][3]
  elseif pswasonboss21 then
    psdeathrepbossnametemp=psbossnames[2][1]
  elseif pswasonboss22 then
    psdeathrepbossnametemp=psbossnames[2][2]
  elseif pswasonboss23 then
    psdeathrepbossnametemp=psbossnames[2][3]
  elseif pswasonboss24 then
    psdeathrepbossnametemp=psbossnames[2][4]
  elseif pswasonboss25 then
    psdeathrepbossnametemp=psbossnames[2][5]
  elseif pswasonboss26 then
    psdeathrepbossnametemp=psbossnames[2][6]
  elseif pswasonboss31 then
    psdeathrepbossnametemp=psbossnames[3][1]
  elseif pswasonboss32 then
    psdeathrepbossnametemp=psbossnames[3][2]
  elseif pswasonboss33 then
    psdeathrepbossnametemp=psbossnames[3][3]
  elseif pswasonboss34 then
    psdeathrepbossnametemp=psbossnames[3][4]
  elseif pswasonboss35 then
    psdeathrepbossnametemp=psbossnames[3][5]
  elseif pswasonboss41 then
    psdeathrepbossnametemp=psbossnames[4][1]
  elseif pswasonboss42 then
    psdeathrepbossnametemp=psbossnames[4][2]
  elseif pswasonboss51 then
    psdeathrepbossnametemp=psbossnames[5][1]
  elseif pswasonboss52 then
    psdeathrepbossnametemp=psbossnames[5][2]
  elseif pswasonboss53 then
    psdeathrepbossnametemp=psbossnames[5][3]
  elseif pswasonboss54 then
    psdeathrepbossnametemp=psbossnames[5][4]
  elseif pswasonboss55 then
    psdeathrepbossnametemp=psbossnames[5][5]
  elseif pswasonboss56 then
    psdeathrepbossnametemp=psbossnames[5][6]
  elseif pswasonboss57 then
    psdeathrepbossnametemp=psbossnames[5][7]
  elseif pswasonboss61 then
    psdeathrepbossnametemp=psbossnames[6][1]
  elseif pswasonboss62 then
    psdeathrepbossnametemp=psbossnames[6][2]
  elseif pswasonboss63 then
    psdeathrepbossnametemp=psbossnames[6][3]
  elseif pswasonboss64 then
    psdeathrepbossnametemp=psbossnames[6][4]
  elseif pswasonboss65 then
    psdeathrepbossnametemp=psbossnames[6][5]
  elseif pswasonboss66 then
    psdeathrepbossnametemp=psbossnames[6][6]
  elseif pswasonboss67 then
    psdeathrepbossnametemp=psbossnames[6][7]
  elseif pswasonboss68 then
    psdeathrepbossnametemp=psbossnames[6][8]
  else
    psdeathrepbossnametemp=nil
  end
end


--не забыть учесть, если игрок УМИРАЕТ ОТ АБИЛКИ что я и так анонсю ФС - и чаты анонсов СОВПАДАЮТ!!! тогда я не анонсю это в фаталити, но засчитываю как номер смерти
--репорты ведь задерживаются прилично, для сбора доп инфы, задерживать фаталити на 3 сек? не много ли ?
